from datetime import datetime

def generate_html_report(report, filename="cfm-report.html"):
    with open(filename, "w", encoding="utf-8") as f:
        f.write(f"""<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8" />
  <title>CodeFixit Report</title>
  <style>
    body {{ font-family: sans-serif; background: #f9f9f9; color: #333; padding: 2em; }}
    h1 {{ color: #3c3c3c; }}
    .section {{ margin-bottom: 2em; }}
    table {{ width: 100%; border-collapse: collapse; }}
    th, td {{ padding: 0.6em; border: 1px solid #ddd; text-align: left; }}
    th {{ background: #f0f0f0; }}
    .footer {{ margin-top: 3em; font-size: 0.9em; color: #777; }}
  </style>
</head>
<body>
  <h1>CodeFixit Report</h1>
  <p><strong>Date:</strong> {datetime.now().isoformat()}</p>

  <div class="section">
    <h2>Summary</h2>
    <p><strong>Total files changed:</strong> {report['total_files_changed']}</p>
  </div>

  <div class="section">
    <h2>Changes by Rule</h2>
    <table>
      <tr><th>Rule</th><th>Occurrences</th></tr>
""")
        for rule, count in report["per_rule"].items():
            f.write(f"<tr><td>{rule}</td><td>{count}</td></tr>\n")

        f.write("""</table>
  </div>

  <div class="section">
    <h2>Changes by File</h2>
    <table>
      <tr><th>File</th><th>Replacements</th></tr>
""")
        for file, count in report["per_file"].items():
            f.write(f"<tr><td>{file}</td><td>{count}</td></tr>\n")

        f.write("""</table>
  </div>

  <div class="footer">
    Report generated by <strong>CodeFixit Manager</strong>.
  </div>
</body>
</html>
""")
    print(f"\n📄 HTML report saved to: {filename}")
